pub struct SparseMatrix<F> { /* private fields */ }Expand description
A sparse matrix implementation using the Compressed Sparse Row (CSR) format.
Implementations
Sourceimpl<F: Field> SparseMatrix<F>
impl<F: Field> SparseMatrix<F>
Sourcepub fn new(
row_offsets: Vec<usize>,
col_indices: Vec<usize>,
values: Vec<F>,
num_cols: usize,
) -> Self
pub fn new( row_offsets: Vec<usize>, col_indices: Vec<usize>, values: Vec<F>, num_cols: usize, ) -> Self
Creates a new sparse matrix from its CSR components.
Sourcepub fn new_rows_cols(num_rows: usize, num_cols: usize) -> SparseMatrix<F>
pub fn new_rows_cols(num_rows: usize, num_cols: usize) -> SparseMatrix<F>
Creates an empty sparse matrix with the specified dimensions.